==> react-image-annotate_ns_demo-5.0.11.tgz: package/Components/AnnotationInput.js <==
/** @format */
import React from "react"; // import { handleTooltipMessage } from '../../utils';

var AnnotationInput = function AnnotationInput(_ref) {
  var ref = _ref.ref,
      isTooltip = _ref.isTooltip,
      isAstrick = _ref.isAstrick,
      readOnly = _ref.readOnly,
      labelClass = _ref.labelClass,
      style = _ref.style,
      title = _ref.title,
      isRequired = _ref.isRequired,
      onChange = _ref.onChange,
      _ref$validation = _ref.validation,
      validation = _ref$validation === void 0 ? false : _ref$validation,
      placeholder = _ref.placeholder,
      value = _ref.value,
      errorMessage = _ref.errorMessage,
      name = _ref.name,
      type = _ref.type,
      onKeyDown = _ref.onKeyDown,
      isDisabled = _ref.isDisabled,
      onblur = _ref.onblur,
      className = _ref.className,
      subTextAboveInput = _ref.subTextAboveInput,
      onFocus = _ref.onFocus,
      count = _ref.count;

  function Count(str) {
    var upper = 0;
    var lower = 0;
    var number = 0;

    for (var i = 0; i < str.length; i++) {
      if (str[i] >= "A" && str[i] <= "Z") upper++;else if (str[i] >= "a" && str[i] <= "z") lower++;else if (str[i] >= "0" && str[i] <= "9") number++;
    }

    return upper + lower + number;
  }

  var handleTooltipMessage = function handleTooltipMessage() {};

  var showCharacterCount = function showCharacterCount(totalCount) {
    return /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: "0.7rem"
      },
      className: "text-green-600 flex justify-start absolute  bottom-2"
    }, String(totalCount).length);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "common_inputBox flex flex-col ".concat(className ? className : "")
  }, title && /*#__PURE__*/React.createElement("label", {
    className: "title_input_box ".concat(labelClass)
  }, title, " ", isRequired ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, isAstrick ? handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: isTooltip
  }) : handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: isTooltip
  })) : ""), subTextAboveInput && /*#__PURE__*/React.createElement("label", null, subTextAboveInput), /*#__PURE__*/React.createElement("input", {
    readOnly: readOnly,
    style: style,
    autoComplete: "off",
    className: "font-MontMedium text-sm",
    onFocus: onFocus,
    name: name,
    type: type,
    placeholder: placeholder,
    value: value,
    onChange: onChange,
    onKeyDown: onKeyDown ? onKeyDown : null,
    disabled: isDisabled,
    onBlur: onblur,
    min: 0,
    spellCheck: false,
    ref: ref
  }), validation && /*#__PURE__*/React.createElement("span", {
    className: "common_error"
  }, errorMessage), (value === null || value === void 0 ? void 0 : value.length) > 0 && count && showCharacterCount(value));
};

export default AnnotationInput;

==> react-image-annotate_ns_demo-5.0.22.tgz: package/Components/AnnotationInput.js <==
/** @format */
import React from "react"; // import { handleTooltipMessage } from '../../utils';

var AnnotationInput = function AnnotationInput(_ref) {
  var ref = _ref.ref,
      isTooltip = _ref.isTooltip,
      isAstrick = _ref.isAstrick,
      readOnly = _ref.readOnly,
      labelClass = _ref.labelClass,
      style = _ref.style,
      title = _ref.title,
      isRequired = _ref.isRequired,
      onChange = _ref.onChange,
      _ref$validation = _ref.validation,
      validation = _ref$validation === void 0 ? false : _ref$validation,
      placeholder = _ref.placeholder,
      value = _ref.value,
      errorMessage = _ref.errorMessage,
      name = _ref.name,
      type = _ref.type,
      onKeyDown = _ref.onKeyDown,
      isDisabled = _ref.isDisabled,
      onblur = _ref.onblur,
      className = _ref.className,
      subTextAboveInput = _ref.subTextAboveInput,
      onFocus = _ref.onFocus,
      count = _ref.count;

  function Count(str) {
    var upper = 0;
    var lower = 0;
    var number = 0;

    for (var i = 0; i < str.length; i++) {
      if (str[i] >= "A" && str[i] <= "Z") upper++;else if (str[i] >= "a" && str[i] <= "z") lower++;else if (str[i] >= "0" && str[i] <= "9") number++;
    }

    return upper + lower + number;
  }

  var handleTooltipMessage = function handleTooltipMessage() {};

  var showCharacterCount = function showCharacterCount(totalCount) {
    return /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: "0.7rem"
      },
      className: "text-green-600 flex justify-start absolute  bottom-2"
    }, String(totalCount).length);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "common_inputBox flex flex-col ".concat(className ? className : "")
  }, title && /*#__PURE__*/React.createElement("label", {
    className: "title_input_box ".concat(labelClass)
  }, title, " ", isRequired ? /*#__PURE__*/React.createElement("span", {
    style: {
      color: "red"
    }
  }, isAstrick ? handleTooltipMessage({
    title: "Mandatory field to proceed with Save & Next",
    count: 2,
    isTooltip: isTooltip
  }) : handleTooltipMessage({
    title: "Mandatory field to proceed with Submit",
    count: 1,
    isTooltip: isTooltip
  })) : ""), subTextAboveInput && /*#__PURE__*/React.createElement("label", null, subTextAboveInput), /*#__PURE__*/React.createElement("textarea", {
    readOnly: readOnly,
    style: style,
    autoComplete: "off",
    className: "font-MontMedium text-sm",
    onFocus: onFocus,
    name: name,
    type: type,
    placeholder: placeholder,
    value: value,
    onChange: onChange,
    onKeyDown: onKeyDown ? onKeyDown : null,
    disabled: isDisabled,
    onBlur: onblur,
    min: 0,
    spellCheck: false,
    ref: ref,
    rows: 3
  }), validation && /*#__PURE__*/React.createElement("span", {
    className: "common_error"
  }, errorMessage), (value === null || value === void 0 ? void 0 : value.length) > 0 && count && showCharacterCount(value));
};

export default AnnotationInput;
